==> nzbget-0.1.1.tar.gz: nzbget-0.1.1/ArticleJob.cpp <==
/*
 *  This file if part of nzbget
 *
 *  Copyright (C) 2004  Sven Henkel <sidddy@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Revision: 1.2 $
 * $Date: 2004/03/03 09:29:34 $
 *
 */


#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "ArticleJob.h"
#include "Job.h"
#include "global.h"

ArticleJob::ArticleJob(char* messageID) : Job(JOBTYPE_ARTICLE)
{
  debug("ArticleJob::ArticleJob(news_article*)\n");
  this->setMessageID(messageID);
  this->resultFilename = NULL;
  this->groups.clear();
}

ArticleJob::~ArticleJob()
{
  this->setResultFilename(NULL);
}

char* ArticleJob::getResultFilename()
{
  return this->resultFilename;
}

void ArticleJob::setResultFilename(char* v)
{
  if (this->resultFilename)
    free(this->resultFilename);

  if (v)
    this->resultFilename = strdup(v);
  else
    this->resultFilename = v;
}

==> nzbget-0.2.0.tar.gz: nzbget-0.2.0/ArticleJob.cpp <==
/*
 *  This file if part of nzbget
 *
 *  Copyright (C) 2004  Sven Henkel <sidddy@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Revision: 1.2 $
 * $Date: 2004/03/03 09:29:34 $
 *
 */


#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "ArticleJob.h"
#include "Job.h"
#include "global.h"

ArticleJob::ArticleJob(char* iMessageID) : Job(JOBTYPE_ARTICLE)
{
	debug("ArticleJob::ArticleJob(news_article*)\n");
	setMessageID( iMessageID );
	m_szResultFilename = NULL;
	m_Groups.clear();
}
                                                 
ArticleJob::~ArticleJob()
{
	setResultFilename(NULL);
}

char* ArticleJob::getResultFilename()
{
	return m_szResultFilename;
}

void ArticleJob::setResultFilename(char* v)
{
	if( m_szResultFilename )
	{
	    free( m_szResultFilename );
	}

	if(v)
	{
		m_szResultFilename = strdup(v);
	}
	else
	{
		m_szResultFilename = NULL;
	}
}
